/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.canvas;

public class Caption extends com.mysql.grt.GrtObject {

    protected Caption() {
    }

    public Caption(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new CaptionDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new CaptionDataGlobal((String) obj);
        }
    }

    public int getFontSize() {
        return ((CaptionData) data).getFontSize();
    }

    public int setFontSize(int fontSize) {
        ((CaptionData) data).setFontSize(fontSize);

        return getFontSize();
    }

    public int getFontWeight() {
        return ((CaptionData) data).getFontWeight();
    }

    public int setFontWeight(int fontWeight) {
        ((CaptionData) data).setFontWeight(fontWeight);

        return getFontWeight();
    }

    public double getConstraintMaxHeight() {
        return ((CaptionData) data).getConstraintMaxHeight();
    }

    public double setConstraintMaxHeight(double constraintMaxHeight) {
        ((CaptionData) data).setConstraintMaxHeight(constraintMaxHeight);

        return getConstraintMaxHeight();
    }

    public double getConstraintMaxWidth() {
        return ((CaptionData) data).getConstraintMaxWidth();
    }

    public double setConstraintMaxWidth(double constraintMaxWidth) {
        ((CaptionData) data).setConstraintMaxWidth(constraintMaxWidth);

        return getConstraintMaxWidth();
    }

    public double getConstraintMinHeight() {
        return ((CaptionData) data).getConstraintMinHeight();
    }

    public double setConstraintMinHeight(double constraintMinHeight) {
        ((CaptionData) data).setConstraintMinHeight(constraintMinHeight);

        return getConstraintMinHeight();
    }

    public double getConstraintMinWidth() {
        return ((CaptionData) data).getConstraintMinWidth();
    }

    public double setConstraintMinWidth(double constraintMinWidth) {
        ((CaptionData) data).setConstraintMinWidth(constraintMinWidth);

        return getConstraintMinWidth();
    }

    public String getText() {
        return ((CaptionData) data).getText();
    }

    public String setText(String text) {
        ((CaptionData) data).setText(text);

        return getText();
    }

    public String getFontFamily() {
        return ((CaptionData) data).getFontFamily();
    }

    public String setFontFamily(String fontFamily) {
        ((CaptionData) data).setFontFamily(fontFamily);

        return getFontFamily();
    }

    public String getFontStyle() {
        return ((CaptionData) data).getFontStyle();
    }

    public String setFontStyle(String fontStyle) {
        ((CaptionData) data).setFontStyle(fontStyle);

        return getFontStyle();
    }

    public String getHorizontalAlignment() {
        return ((CaptionData) data).getHorizontalAlignment();
    }

    public String setHorizontalAlignment(String horizontalAlignment) {
        ((CaptionData) data).setHorizontalAlignment(horizontalAlignment);

        return getHorizontalAlignment();
    }

    public String getVerticalAlignment() {
        return ((CaptionData) data).getVerticalAlignment();
    }

    public String setVerticalAlignment(String verticalAlignment) {
        ((CaptionData) data).setVerticalAlignment(verticalAlignment);

        return getVerticalAlignment();
    }

    public String getColor() {
        return ((CaptionData) data).getColor();
    }

    public String setColor(String color) {
        ((CaptionData) data).setColor(color);

        return getColor();
    }

    public String getBidiMode() {
        return ((CaptionData) data).getBidiMode();
    }

    public String setBidiMode(String bidiMode) {
        ((CaptionData) data).setBidiMode(bidiMode);

        return getBidiMode();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"fontSize\">"
                    + Integer.toString(getFontSize()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"fontWeight\">"
                    + Integer.toString(getFontWeight()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"constraintMaxHeight\">"
                    + Double.toString(getConstraintMaxHeight()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"constraintMaxWidth\">"
                    + Double.toString(getConstraintMaxWidth()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"constraintMinHeight\">"
                    + Double.toString(getConstraintMinHeight()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"constraintMinWidth\">"
                    + Double.toString(getConstraintMinWidth()) + "</value>\n");

            if (getText() != null) {
                xml.append("<value type=\"string\" key=\"text\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getText()) + "</value>\n");
            }

            if (getFontFamily() != null) {
                xml.append("<value type=\"string\" key=\"fontFamily\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getFontFamily()) + "</value>\n");
            }

            if (getFontStyle() != null) {
                xml.append("<value type=\"string\" key=\"fontStyle\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getFontStyle()) + "</value>\n");
            }

            if (getHorizontalAlignment() != null) {
                xml.append("<value type=\"string\" key=\"horizontalAlignment\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getHorizontalAlignment()) + "</value>\n");
            }

            if (getVerticalAlignment() != null) {
                xml.append("<value type=\"string\" key=\"verticalAlignment\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getVerticalAlignment()) + "</value>\n");
            }

            if (getColor() != null) {
                xml.append("<value type=\"string\" key=\"color\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getColor()) + "</value>\n");
            }

            if (getBidiMode() != null) {
                xml.append("<value type=\"string\" key=\"bidiMode\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getBidiMode()) + "</value>\n");
            }

        return xml;
    }
}
