/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db;

public class IndexColumn extends com.mysql.grt.GrtObject {

    protected IndexColumn() {
    }

    public IndexColumn(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new IndexColumnDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new IndexColumnDataGlobal((String) obj);
        }
    }

    public int getColumnLength() {
        return ((IndexColumnData) data).getColumnLength();
    }

    public int setColumnLength(int columnLength) {
        ((IndexColumnData) data).setColumnLength(columnLength);

        return getColumnLength();
    }

    public int getDescend() {
        return ((IndexColumnData) data).getDescend();
    }

    public int setDescend(int descend) {
        ((IndexColumnData) data).setDescend(descend);

        return getDescend();
    }

    public String getStoredFunction() {
        return ((IndexColumnData) data).getStoredFunction();
    }

    public String setStoredFunction(String storedFunction) {
        ((IndexColumnData) data).setStoredFunction(storedFunction);

        return getStoredFunction();
    }

    public String getComment() {
        return ((IndexColumnData) data).getComment();
    }

    public String setComment(String comment) {
        ((IndexColumnData) data).setComment(comment);

        return getComment();
    }

    public com.mysql.grt.db.Column getReferedColumn() {
        return ((IndexColumnData) data).getReferedColumn();
    }

    public com.mysql.grt.db.Column setReferedColumn(com.mysql.grt.db.Column referedColumn) {
        ((IndexColumnData) data).setReferedColumn(referedColumn);

        return getReferedColumn();
    }

    public String getReferedColumnById() {
        return ((IndexColumnData) data).getReferedColumnById();
    }

    public void setReferedColumnById(String referedColumn) {
        ((IndexColumnData) data).setReferedColumnById(referedColumn);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"columnLength\">"
                    + Integer.toString(getColumnLength()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"descend\">"
                    + Integer.toString(getDescend()) + "</value>\n");

            if (getStoredFunction() != null) {
                xml.append("<value type=\"string\" key=\"storedFunction\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getStoredFunction()) + "</value>\n");
            }

            if (getComment() != null) {
                xml.append("<value type=\"string\" key=\"comment\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getComment()) + "</value>\n");
            }

            if (getReferedColumn() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"referedColumn\">"
                        + getReferedColumnById() + "</value>\n");
            }

        return xml;
    }
}
