/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.migration;

public class Mapping extends com.mysql.grt.GrtObject {

    protected Mapping() {
    }

    public Mapping(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new MappingDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new MappingDataGlobal((String) obj);
        }
    }

    public String getSourceStructName() {
        return ((MappingData) data).getSourceStructName();
    }

    public String setSourceStructName(String sourceStructName) {
        ((MappingData) data).setSourceStructName(sourceStructName);

        return getSourceStructName();
    }

    public String getMethodName() {
        return ((MappingData) data).getMethodName();
    }

    public String setMethodName(String methodName) {
        ((MappingData) data).setMethodName(methodName);

        return getMethodName();
    }

    public String getModuleName() {
        return ((MappingData) data).getModuleName();
    }

    public String setModuleName(String moduleName) {
        ((MappingData) data).setModuleName(moduleName);

        return getModuleName();
    }

    public String getParamGroupName() {
        return ((MappingData) data).getParamGroupName();
    }

    public String setParamGroupName(String paramGroupName) {
        ((MappingData) data).setParamGroupName(paramGroupName);

        return getParamGroupName();
    }

    public com.mysql.grt.GrtStringHashMap getParams() {
        return ((MappingData) data).getParams();
    }

    public com.mysql.grt.GrtStringHashMap setParams(com.mysql.grt.GrtStringHashMap params) {
        ((MappingData) data).setParams(params);

        return getParams();
    }

    public com.mysql.grt.GrtObject getSourceObject() {
        return ((MappingData) data).getSourceObject();
    }

    public com.mysql.grt.GrtObject setSourceObject(com.mysql.grt.GrtObject sourceObject) {
        ((MappingData) data).setSourceObject(sourceObject);

        return getSourceObject();
    }

    public String getSourceObjectById() {
        return ((MappingData) data).getSourceObjectById();
    }

    public void setSourceObjectById(String sourceObject) {
        ((MappingData) data).setSourceObjectById(sourceObject);
    }

    public com.mysql.grt.db.migration.Method getMethod() {
        return ((MappingData) data).getMethod();
    }

    public com.mysql.grt.db.migration.Method setMethod(com.mysql.grt.db.migration.Method method) {
        ((MappingData) data).setMethod(method);

        return getMethod();
    }

    public String getMethodById() {
        return ((MappingData) data).getMethodById();
    }

    public void setMethodById(String method) {
        ((MappingData) data).setMethodById(method);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            if (getSourceStructName() != null) {
                xml.append("<value type=\"string\" key=\"sourceStructName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getSourceStructName()) + "</value>\n");
            }

            if (getMethodName() != null) {
                xml.append("<value type=\"string\" key=\"methodName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getMethodName()) + "</value>\n");
            }

            if (getModuleName() != null) {
                xml.append("<value type=\"string\" key=\"moduleName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getModuleName()) + "</value>\n");
            }

            if (getParamGroupName() != null) {
                xml.append("<value type=\"string\" key=\"paramGroupName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getParamGroupName()) + "</value>\n");
            }

            if (getParams() != null) {
                getParams().getGrtXml(xml, " key=\"params\"");
            }

            if (getSourceObject() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"sourceObject\">"
                        + getSourceObjectById() + "</value>\n");
            }

            if (getMethod() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"method\">"
                        + getMethodById() + "</value>\n");
            }

        return xml;
    }
}
